@@ -163,8 +163,6 @@ _accept_call(Slide2AnswerStatusPlugin* plugin)
 
 static void
 _slider_changed(GtkRange* range,
-		/*		GtkScrollType scroll,
-				gdouble value,*/
 		gpointer user_data)
 {
   if(IS_SLIDE2ANSWER_STATUS_PLUGIN(user_data))
@@ -172,7 +170,6 @@ _slider_changed(GtkRange* range,
 
     Slide2AnswerStatusPlugin* plugin = SLIDE2ANSWER_STATUS_PLUGIN(user_data);
     double value = gtk_range_get_value(GTK_RANGE(plugin->priv->call_window_slider));
-    g_warning("value changed\n");
     if(value>0.9)
     {
       gtk_widget_hide(GTK_WIDGET(plugin->priv->call_window));
@@ -188,7 +185,6 @@ _slider_changed(GtkRange* range,
       gtk_range_set_value(GTK_RANGE(plugin->priv->call_window_slider), 0.0);
     }
   }
-
 }
 
 static void
@@ -206,9 +202,16 @@ _create_slide2answer_window(Slide2AnswerStatusPlugin* status_plugin)
   status_plugin->priv->call_window_number_label = gtk_label_new("");
   hildon_helper_set_logical_font(status_plugin->priv->call_window_number_label, "SmallSystemFont");
 
-  status_plugin->priv->call_window_slider = hildon_gtk_hscale_new();  
-  gtk_range_set_range(GTK_RANGE(status_plugin->priv->call_window_slider), -1.0, 1.0);              
+  status_plugin->priv->call_window_slider = hildon_gtk_hscale_new();
+  /*
+  gtk_range_set_range(GTK_RANGE(status_plugin->priv->call_window_slider), -1.0, 1.0);
   gtk_range_set_value(GTK_RANGE(status_plugin->priv->call_window_slider), 0.0);
+  */
+  g_object_set(status_plugin->priv->call_window_slider, "jump-to-position", FALSE, NULL);
+
+  GtkObject* adju = gtk_adjustment_new (0.0, -1.0, 1.0, 0.1, 0.0, 0.0);
+  gtk_range_set_adjustment(GTK_RANGE(status_plugin->priv->call_window_slider), GTK_ADJUSTMENT(adju));
+
   gtk_range_set_update_policy(GTK_RANGE(status_plugin->priv->call_window_slider), GTK_UPDATE_DISCONTINUOUS);
   gtk_widget_set_name(status_plugin->priv->call_window_slider,
 		      "sui-tklock-slider");
